<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>TabBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Show tab bar</source>
        <translation>Wyświetlanie paska kart</translation>
    </message>
    <message>
        <location filename="../TabBar.js" line="+24"/>
        <source>Widgets</source>
        <translation>Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Tab Bar</source>
        <translation>Pasek kart</translation>
    </message>
</context>
</TS>
